# Generated by Django 4.2.5 on 2023-10-02 11:02

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("df_remote_config", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="ConfigAttribute",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255)),
                ("value", models.CharField(max_length=255)),
            ],
            options={
                "unique_together": {("name", "value")},
            },
        ),
        migrations.AlterModelOptions(
            name="configpart",
            options={"ordering": ("sequence",)},
        ),
        migrations.RemoveField(
            model_name="configpart",
            name="tags",
        ),
        migrations.DeleteModel(
            name="ConfigTag",
        ),
        migrations.AddField(
            model_name="configpart",
            name="attributes",
            field=models.ManyToManyField(
                blank=True, to="df_remote_config.configattribute"
            ),
        ),
    ]
