# Generated by Django 4.2.5 on 2023-10-02 05:00

import df_remote_config.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="ConfigTag",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name="ConfigPart",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    df_remote_config.fields.NoMigrationsChoicesField(max_length=255),
                ),
                ("sequence", models.PositiveIntegerField(default=1000)),
                ("json", models.JSONField(blank=True, default=dict)),
                (
                    "tags",
                    models.ManyToManyField(blank=True, to="df_remote_config.configtag"),
                ),
            ],
        ),
    ]
